<?php
//////////////////////////////////////////////////////////////////////////////////
//    					 copyright (c) Arfooo Annuaire                          //
//   				 by Hocine Guillaume (c) 2007 - 2008                        //
//       					http://www.arfooo.com/                              //
//    Licence Creative Commons http://creativecommons.org/licenses/by/2.0/fr/   //
//////////////////////////////////////////////////////////////////////////////////

/**
 * Class which handle naming convenction
 */
class NameTool
{
    /**
     * Get camelized version of string
     * @param  string $underscored_string Underscore string 
     * @return string 
     */
    public static function camelize($underscored_string)
    {
        $camelized = str_replace(" ", "", ucwords(str_replace("_", " ", $underscored_string)));
        return $camelized;
    }
    
    /**
     * Get underscored version of string
     * @param  string $camelcased_string CamelCased string 
     * @return string 
     */ 
    public static function underscore($camelcased_string)
    {
        $underscore = strtolower(preg_replace('/(?<=\\w)([A-Z])/', '_\\1', $camelcased_string));
        return $underscore;
    }
            
    /**
     * Get controller file name basing on its name
     * @param  string $controller_name Name of controller  
     * @return string 
     */
    public static function getControllerFileName($controller_name)
    {
        $path = ucfirst($controller_name)."Controller.php";
        return $path; 
    } 

    /**
     * Add extension to template path
     * @param  string $path withoout extension  
     * @return string 
     */    
    public static function getTemplateFileName($path)
    {                                      
        $path .= ".tpl";
        return $path; 
    }

    /**
     * Get controller class name basing on its name and path where is placed
     * @param  string controller_name Controller name 
     * @return string 
     */     
    public static function getControllerClassName($controller_name, $path="")
    {
        $class_name = ""; 
        if($path)
        {
            $parts = explode("/", $path);
            foreach($parts as $dir)
            {
                $class_name .= ucfirst(strtolower($dir))."_";    
            }
        }

        $class_name .= self::camelize($controller_name)."Controller";
        return $class_name;
    }
}
?>